QuickStart
======================

.. include:: ../README.md
   :start-after: <!-- sphinx start -->
   :end-before: <!-- sphinx end -->
   :parser: myst_parser.sphinx_

Table of Contents
-----------------

.. toctree::

   self

.. toctree::
   :caption: Reference

   mons (Everest)<everest>
   mods<mods>
